<?php
namespace Teknisa\TCO\Services;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DependencyInjection\InstanceManager;

use Teknisa\Libs\Util\SMTP;

use Teknisa\TCO\Util\TcoUtil;

class Tco01100SMTP {
	
	private $conn;
	private $env;
	private $pathToSave = '/tmp/';
	private $temporaryAttachments = [];
	private $smtpParams = [];
	private $subject = '';

	public function __construct($connection, $environment, $smtpParams = []){
		$this->conn = $connection;
		$this->env = $environment;
		if(empty($smtpParams)){
			$this->smtpParams = InstanceManager::getInstance()->getParameter('smtp_params');
		} else {
			$this->smtpParams = $smtpParams;
		}
	}

	private function timeStamp(){
		return (new \DateTime())->getTimestamp();
	}

	public function addReportToAttachment($reportUrl, $nameFile, $extension = 'pdf') {
		$reportUrl = $reportUrl;
		$pathToSave = $pathToSave ?? $this->pathToSave;
		$time = $this->timeStamp();
		$filePath = $pathToSave."/{$nameFile}_$time.$extension";
		file_put_contents($filePath, fopen($reportUrl, 'r'));
		$this->temporaryAttachments[$filePath] = "$nameFile.$extension";
		
		return $filePath;
	}

	public function deleteTemporaryFiles(){
		foreach ( $this->temporaryAttachments as $fileToDelete => $mailFile ) {
			if(realpath($fileToDelete)) unlink($fileToDelete);
		}
	}

	public function sendMail($message, $address, $addressCC = '', $addressBCC = '', $addressReplyTo = ''){
		$smtp = new SMTP($this->smtpParams);
		if(!empty($this->temporaryAttachments)){
			foreach($this->temporaryAttachments as $fileToAdd => $mailFile) {
				$smtp->addAttachment($fileToAdd, $mailFile);
			}
		}
		if(!empty($this->subject)){
			$smtp->setSubject($this->subject);
		}
		$smtp->sendMail($message, $address, $addressCC, $addressBCC, $addressReplyTo);
	}

	public function setSubject( $subject ){
		$this->subject = $subject;
	}

	public function setPathToSave( $pathToSave ) {
		$this->pathToSave = $pathToSave;
	}

	public function getSubject(){
		return $this->subject;
	}

	public function getPathToSave() {
		return $this->pathToSave;
	}

	public function setSmtpParams($smtpParams) {
		$this->smtpParams = $smtpParams;
	}

	public function getSmtpParams(){
		return $this->smtpParams;
	}
}